rnalysis.feature\_name\_to\_wbgene.GeneNameTranslator.read\_reference
=====================================================================

.. currentmodule:: rnalysis.feature_name_to_wbgene

.. automethod:: GeneNameTranslator.read_reference